==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/af/af02ddd5d9d1888f0ea757b114f06c83.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @MauticLead/KeyboardShortcuts/lead_shortcuts.html.twig */
class __TwigTemplate_c248d719d5613d373d2c545530e19758 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        $context["shortcuts"] = ["contacts" => ["a" => "mautic.keyboard.quick_add_contact", "v" => "mautic.keyboard.toggle_view"]];
        // line 7
        yield "
";
        // line 8
        yield from         $this->loadTemplate("@MauticCore/Helper/keyboard_shortcuts_helper.html.twig", "@MauticLead/KeyboardShortcuts/lead_shortcuts.html.twig", 8)->unwrap()->yield(CoreExtension::merge($context, ["shortcuts" => (isset($context["shortcuts"]) || array_key_exists("shortcuts", $context) ? $context["shortcuts"] : (function () { throw new RuntimeError('Variable "shortcuts" does not exist.', 8, $this->source); })())]));
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@MauticLead/KeyboardShortcuts/lead_shortcuts.html.twig";
    }

    /**
     * @codeCoverageIgnore
     */
    public function isTraitable(): bool
    {
        return false;
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  47 => 8,  44 => 7,  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@MauticLead/KeyboardShortcuts/lead_shortcuts.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Resources/views/KeyboardShortcuts/lead_shortcuts.html.twig");
    }
}

==> production-demo-20260214_152721.tar.gz: var/www/html/production-demo/var/tmp/twig/af/af02ddd5d9d1888f0ea757b114f06c83.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @MauticLead/KeyboardShortcuts/lead_shortcuts.html.twig */
class __TwigTemplate_c248d719d5613d373d2c545530e19758 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        $context["shortcuts"] = ["contacts" => ["a" => "mautic.keyboard.quick_add_contact", "v" => "mautic.keyboard.toggle_view"]];
        // line 7
        yield "
";
        // line 8
        yield from         $this->loadTemplate("@MauticCore/Helper/keyboard_shortcuts_helper.html.twig", "@MauticLead/KeyboardShortcuts/lead_shortcuts.html.twig", 8)->unwrap()->yield(CoreExtension::merge($context, ["shortcuts" => (isset($context["shortcuts"]) || array_key_exists("shortcuts", $context) ? $context["shortcuts"] : (function () { throw new RuntimeError('Variable "shortcuts" does not exist.', 8, $this->source); })())]));
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@MauticLead/KeyboardShortcuts/lead_shortcuts.html.twig";
    }

    /**
     * @codeCoverageIgnore
     */
    public function isTraitable(): bool
    {
        return false;
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  47 => 8,  44 => 7,  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@MauticLead/KeyboardShortcuts/lead_shortcuts.html.twig", "/var/www/html/production-demo/app/bundles/LeadBundle/Resources/views/KeyboardShortcuts/lead_shortcuts.html.twig");
    }
}
